%{?scl:%scl_package libomp}
%{!?scl:%global pkg_name %{name}}
%ifarch ppc64le
%global libomp_arch ppc64
%else
%global libomp_arch %{_arch}
%endif

%ifnarch i686
%global enable_test_pkg 1
%endif

Name: %{?scl_prefix}libomp
Version: 7.0.1
Release: 2%{?dist}
Summary: OpenMP runtime for clang

License: NCSA
URL: http://openmp.llvm.org	
Source0: http://llvm.org/releases/%{version}/openmp-%{version}.src.tar.xz
Source1: runtest.sh

Patch0: 0001-CMake-Make-LIBOMP_HEADERS_INSTALL_PATH-a-cache-varia.patch
Patch1: 0001-openmp-Use-glibc-wrappers-for-accessing-cpu-affinity.patch
Patch2: 0001-Fix-for-https-bugs.llvm.org-show_bug.cgi-id-39970.patch

BuildRequires: %{?scl_prefix}cmake
BuildRequires: elfutils-libelf-devel
BuildRequires: perl
BuildRequires: perl-Data-Dumper
BuildRequires: perl-Encode
BuildRequires: libffi-devel

Requires: elfutils-libelf%{?isa}

# libomp does not support s390x.
ExcludeArch: s390x

%description
OpenMP runtime for clang.

%package devel
Summary: OpenMP header files
Requires: %{?scl_prefix}clang-devel%{?isa} = %{version}

%description devel
OpenMP header files.

%if 0%{?enable_test_pkg}

%package test
Summary: OpenMP regression tests
Requires: %{?scl_prefix}libomp%{?isa} = %{version}
Requires: %{?scl_prefix}libomp-devel%{?isa} = %{version}
Requires: %{?scl_prefix}clang
Requires: %{?scl_prefix}llvm
Requires: gcc
Requires: gcc-c++
Requires: %{?scl_prefix}python2-lit

%description test
OpenMP regression tests

%endif

%prep
%autosetup -n openmp-%{version}.src -p1

# Fix paths in test script
sed -i 's~/usr/share~%{_datadir}~g' %{SOURCE1}

%build
mkdir -p _build
cd _build

# Use the scl-provided cmake instead of /usr/bin/cmake
%global __cmake %{_bindir}/cmake

%cmake .. \
	-DLIBOMP_INSTALL_ALIASES=OFF \
	-DLIBOMP_HEADERS_INSTALL_PATH:PATH=%{_libdir}/clang/%{version}/include \
%if 0%{?__isa_bits} == 64
	-DOPENMP_LIBDIR_SUFFIX=64 \
%else
	-DOPENMP_LIBDIR_SUFFIX= \
%endif

%make_build


%install
%make_install -C _build

%if 0%{?enable_test_pkg}

# Test package setup
%global libomp_srcdir %{_datadir}/libomp/src/
%global libomp_testdir %{libomp_srcdir}/runtime/test/
%global gcc_lit_cfg %{buildroot}%{libomp_testdir}/gcc.site.cfg
%global clang_lit_cfg %{buildroot}%{libomp_testdir}/clang.site.cfg

install -d %{buildroot}%{libomp_srcdir}/runtime
cp -R runtime/test  %{buildroot}%{libomp_srcdir}/runtime
cp -R runtime/src  %{buildroot}%{libomp_srcdir}/runtime

# Remove patch backups that get installed
find %{buildroot}%{libomp_srcdir} -iname '*.orig' -exec rm -f {} \;

# Add symlinks to the libomp headers/library so gcc can find them.
ln -s %{_libdir}/clang/%{version}/include/omp.h %{buildroot}%{libomp_testdir}/omp.h
ln -s %{_libdir}/clang/%{version}/include/ompt.h %{buildroot}%{libomp_testdir}/ompt.h
ln -s %{_libdir}/libomp.so %{buildroot}%{libomp_testdir}/libgomp.so

# Generic test config
echo "import tempfile" > %{gcc_lit_cfg}
cat _build/runtime/test/lit.site.cfg >> %{gcc_lit_cfg}
sed -i 's~\(config.test_filecheck = \)""~\1"%{_libdir}/llvm/FileCheck"~' %{gcc_lit_cfg}
sed -i 's~\(config.omp_header_directory = \)"[^"]\+"~\1"%{_includedir}"~' %{gcc_lit_cfg}
sed -i 's~\(config.libomp_obj_root = \)"[^"]\+"~\1tempfile.mkdtemp()[1]~' %{gcc_lit_cfg}
sed -i 's~\(lit_config.load_config(config, \)"[^"]\+"~\1"%{libomp_testdir}/lit.cfg"~' %{gcc_lit_cfg}

# GCC config
# test_compiler_features was already populated with gcc information if gcc was used
# to compile libomp.
sed -i 's~\(config.test_c_compiler = \)"[^"]\+"~\1"%{_bindir}/gcc"~' %{gcc_lit_cfg}
sed -i 's~\(config.test_cxx_compiler = \)"[^"]\+"~\1"%{_bindir}/g++"~' %{gcc_lit_cfg}
sed -i 's~\(config.library_dir = \)"[^"]\+"~\1"%{libomp_testdir}"~' %{gcc_lit_cfg}

# Clang config
cp %{gcc_lit_cfg} %{clang_lit_cfg}
sed -i 's~\(config.test_compiler_features = \)\[[^\[]\+]~\1["clang"]~' %{clang_lit_cfg}
sed -i 's~\(config.test_c_compiler = \)"[^"]\+"~\1"%{_bindir}/clang"~' %{clang_lit_cfg}
sed -i 's~\(config.test_cxx_compiler = \)"[^"]\+"~\1"%{_bindir}/clang++"~' %{clang_lit_cfg}
sed -i 's~\(config.library_dir = \)"[^"]\+"~\1"%{_libdir}"~' %{clang_lit_cfg}
# rhbz#1558565
%ifarch ppc64le
sed -i 's~has_libatomic = True~has_libatomic = False~' %{clang_lit_cfg}
%endif

install -m 0755 %{SOURCE1} %{buildroot}%{_datadir}/libomp

%endif

%files
%{_libdir}/libomp.so
%{_libdir}/libomptarget.so
%ifnarch %{arm} %{ix86}
%{_libdir}/libomptarget.rtl.%{libomp_arch}.so
%endif

%files devel
%{_libdir}/clang/%{version}/include/omp.h
%ifnarch %{arm}
%{_libdir}/clang/%{version}/include/ompt.h
%endif

%if 0%{?enable_test_pkg}
%files test
%{_datadir}/libomp
%endif


%changelog
* Thu Jan 10 2019 Tom Stellard <tstellar@redhat.com> - 7.0.1-2
- Rebuild for i686

* Wed Jan 09 2019 Tom Stellard <tstellar@redhat.com> - 7.0.1-1
- 7.0.1 Release

* Tue Sep 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-7
- Don't install patch backup files

* Tue Sep 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-6
- Drop libatomic test dependency on ppc64le

* Tue Sep 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-5
- Fix lit test failures on ppc64

* Mon Sep 10 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-4
- Remove gcc tests from runtest.sh

* Mon Sep 10 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-3
- Fix path in runtest.sh

* Sat Sep 08 2018 Edjunior Barbosa Machado <emachado@redhat.com> - 6.0.1-2
- Depend on python2 instead of python3

* Wed Jul 11 2018 Tom Stellard <tstellar@redhat.com> - 6.0.1-1
- 6.0.1 Release

* Mon Jan 15 2018 Tom Stellard <tstellar@redhat.com> - 5.0.1-2
- Rebuild to include i686

* Thu Dec 21 2017 Tom Stellard <tstellar@redhat.com> - 5.0.1-1
- 5.0.1 Release.

* Wed Jun 21 2017 Tom Stellard <tstellar@redhat.com> - 4.0.1-1
- 4.0.1 Release.

* Wed Jun 07 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-3
- Rename libopenmp->libomp

* Fri May 26 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-2
- Disable build on s390x

* Mon May 15 2017 Tom Stellard <tstellar@redhat.com> - 4.0.0-1
- Initial version.
